#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quote-quot
version:              0.2.1.0
visibility:           public
id:                   quote-quot-0.2.1.0-Lj3LI5CN3Ku6q8dUQ937zO
key:                  quote-quot-0.2.1.0-Lj3LI5CN3Ku6q8dUQ937zO
license:              BSD-3-Clause
copyright:            2020-2022 Andrew Lelechenko
maintainer:           andrew.lelechenko@gmail.com
author:               Andrew Lelechenko
homepage:             https://github.com/Bodigrim/quote-quot#readme
synopsis:             Divide without division
description:
    Generate routines for integer division, employing arithmetic
    and bitwise operations only, which are __2.5x-3.5x faster__
    than '\''quot'\''. Divisors must be known in compile-time and be positive.

category:             Math, Numerical
abi:                  3463c633b4281066493884f4cf00eb29
exposed:              True
exposed-modules:      Numeric.QuoteQuot
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quote-quot-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quote-quot-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quote-quot-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quote-quot
hs-libraries:         HSquote-quot-0.2.1.0-Lj3LI5CN3Ku6q8dUQ937zO
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:   /usr/share/doc/haskell-quote-quot/html/quote-quot.haddock
haddock-html:         /usr/share/doc/haskell-quote-quot/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

